module, require("react"), define, define.amd, define([
    "exports",
    "react"
], ha);
